Description Usage Arguments Examples
summary.tuts_LS Function returning a list of frequencies for which spectral power exceeds prespecified
confidence interval contained in tuts_LS objects.
1 2 | ## S3 method for class 'tuts_ls'
summary(x)
|
x |
A tuts_LS obect. |
1 2 3 4 5 6 7 8 9 | # Simulate time-uncertain time series:
DATA=simtuts(N=100,Harmonics=c(10,30,0), sin.ampl=c(10,10, 0), cos.ampl=c(0,0,0),
trend=0,y.sd=3, ti.sd=1)
# (Set parameters and ) run multiple Lomb-Scargle periodograms:
TULS=tuls(y=y,ti.mu=ti.mu,ti.sd=ti.sd) # Optional parameters: ofac, CI, n.sim.
# Obtain list of frequencies for which spectral power exceeds prespecified confidence interval
summary(TULS)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.