Learn R Programming

tuts (version 0.1.1)

summary.tuts_poisBFS: Summary tables of tuts_poisBFS objects

Description

summary.tuts_poisBFS prints summary tables of tuts_poisBFS objects.

Usage

# S3 method for tuts_poisBFS
summary(object, ...)

Arguments

object

A tuts_poisBFS object.

...

A list of optional parameters: - burn: burn-in parameter ranging from 0 to 0.7, the default value is 0. - CI: confidence interval, the default value is set to 0.99.

Examples

Run this code
# NOT RUN {
# Note: Most of models included in tuts package are computationally intensive. In the example
# below I set parameters to meet CRAN<U+2019>s testing requirement of maximum 5 sec per example.
# A more practical example would contain N=50 in the first line of the code and n.sim=10000.

 #1. Import or simulate the data (simulation is chosen for illustrative purposes):
DATA=simtuts(N=7,Harmonics=c(4,0,0), sin.ampl=c(10,0, 0), cos.ampl=c(0,0,0),
            trend=0,y.sd=2, ti.sd=0.2)
y=DATA$observed$y.obs
y=round(y-min(y))
ti.mu=DATA$observed$ti.obs.tnorm
ti.sd= rep(0.2, length(ti.mu))

#2. Fit the model:
n.sim=10
TUPOIS=tupoisbsf(y=y,ti.mu=ti.mu,ti.sd=ti.sd,freqs='internal',n.sim=n.sim,n.chains=2, CV=FALSE)

#3. Generate summary results (optional parameters are listed in brackets):
summary(TUPOIS)                               # Summary results (CI, burn).
summary(TUPOIS,burn=0.2)                      # Results after 20% of burn-in (CI).

# }

Run the code above in your browser using DataLab