Description Usage Arguments References See Also Examples
tuls computes multiple power estimates using the Lomb-Scargle algorithm and simulated realizations of
timings of observations. Timings are simulated with normal distribution ti~N(ti.mu,ti.sd),
and sorted in ascending order to ensure non-overlapping feature of observations.
1 |
y |
A vector of observations. |
ti.mu |
A vector of estimates of timings of observations. |
ti.sd |
A vector of standard deviations of timings. |
... |
A list of optional parameters. The list contains thinning oversamlping parameter, the default value is ofac=4, confidence interval, the default value is CI=0.99, and the number of simulated timings, wiith the default vale set to n.sim=1000. |
n.sim |
A number of simulations. |
https://en.wikipedia.org/wiki/Least-squares_spectral_analysis
http://cran.r-project.org/package=Bchron
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | # Import or simulate the data (simulation is chosen for illustrative purposes):
DATA=simtuts(N=50,Harmonics=c(10,30,0), sin.ampl=c(10,10, 0), cos.ampl=c(0,0,0),
trend=0,y.sd=3, ti.sd=1)
y=DATA$observed$y.obs
ti.mu=DATA$observed$ti.obs.tnorm
ti.sd= rep(1, length(ti.mu))
# (Set parameters and ) run multiple Lomb-Scargle periodograms:
TULS=tuls(y=y,ti.mu=ti.mu,ti.sd=ti.sd) # Optional parameters: ofac, CI, n.sim
# Plot the results:
plot(TULS)
# Obtain list of frequencies for which spectral power exceeds confidence interval prespecified in the tuts_ls class
summary(TULS)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.